@@ -44,6 +44,7 @@ pub struct Module {
     pub(crate) subsystem_id: Option<i64>,
     pub(crate) syssig_ch: Option<Receiver<i32>>,
     pub(crate) name: String,
+    onto_types: Vec<String>,
 }
 
 impl Default for Module {
@@ -106,6 +107,23 @@ impl Module {
             }
         }
 
+        let onto_types = vec![
+            "rdfs:Class",
+            "owl:Class",
+            "rdfs:Datatype",
+            "owl:Ontology",
+            "rdf:Property",
+            "owl:DatatypeProperty",
+            "owl:ObjectProperty",
+            "owl:OntologyProperty",
+            "owl:AnnotationProperty",
+            "v-ui:PropertySpecification",
+            "v-ui:DatatypePropertySpecification",
+            "v-ui:ObjectPropertySpecification",
+            "v-ui:TemplateSpecification",
+            "v-ui:ClassModel",
+        ];
+
         Module {
             queue_prepared_count: 0,
             notify_channel_url,
@@ -117,6 +135,7 @@ impl Module {
             notify_channel_read_timeout,
             syssig_ch: None,
             name: module_name.to_owned(),
+            onto_types: onto_types.iter().map(|x| x.to_string()).collect(),
         }
     }
 
@@ -150,6 +169,17 @@ impl Module {
         None
     }
 
+    pub fn is_content_onto(&self, cmd: IndvOp, new_state: &mut Individual, prev_state: &mut Individual) -> bool {
+        if cmd != IndvOp::Remove {
+            if new_state.any_exists_v("rdf:type", &self.onto_types) {
+                return true;
+            }
+        } else if prev_state.any_exists_v("rdf:type", &self.onto_types) {
+            return true;
+        }
+        false
+    }
+
     pub fn get_sys_ticket_id_from_db(storage: &mut VStorage) -> Result<String, i32> {
         let mut indv = Individual::default();
         if storage.get_individual_from_db(StorageId::Tickets, "systicket", &mut indv) {
